Stan Math Library: stan/math/prim/scal/prob/exponential_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exponential_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_EXPONENTIAL_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_EXPONENTIAL_RNG_HPP
3
4 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
5 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
6 #include <stan/math/prim/scal/err/check_not_nan.hpp>
7 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
8 #include <stan/math/prim/scal/fun/value_of.hpp>
9 #include <stan/math/prim/scal/meta/length.hpp>
10 #include <stan/math/prim/scal/meta/VectorView.hpp>
11 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
12 #include <stan/math/prim/scal/meta/return_type.hpp>
13 #include <stan/math/prim/scal/fun/constants.hpp>
14 #include <stan/math/prim/scal/meta/include_summand.hpp>
15 #include <boost/random/exponential_distribution.hpp>
16 #include <boost/random/variate_generator.hpp>
17
18 namespace stan {
19
20 namespace math {
21
22 template <class RNG>
23 inline double
24 exponential_rng(const double beta,
25 RNG& rng) {
26 using boost::variate_generator;
27 using boost::exponential_distribution;
28
29 static const char* function("stan::math::exponential_rng");
30
31 using stan::math::check_positive_finite;
32
33 check_positive_finite(function, "Inverse scale parameter", beta);
34
35 variate_generator<RNG&, exponential_distribution<> >
36 exp_rng(rng, exponential_distribution<>(beta));
37 return exp_rng();
38 }
39 }
40 }
41
42 #endif
check_not_nan.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
return_type.hpp
stan::math::exponential_rng
double exponential_rng(const double beta, RNG &rng)
Definition: exponential_rng.hpp:24
include_summand.hpp
check_nonnegative.hpp
VectorView.hpp
VectorBuilder.hpp
length.hpp
constants.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.